@@ -114,8 +114,19 @@ class Chat(Object):
         last_name (``str``, *optional*):
             Last name of the other party in a private chat, for private chats.
 
+        personal_photo (:obj:`~pyrogram.types.ChatPhoto`, *optional*):
+            Chat profile photo set by the current user for the contact.
+            This photo isn't returned in the list of chat photos.
+            Suitable for downloads only.
+
         photo (:obj:`~pyrogram.types.ChatPhoto`, *optional*):
-            Chat photo. Suitable for downloads only.
+            Chat photo.
+            Suitable for downloads only.
+
+        public_photo (:obj:`~pyrogram.types.ChatPhoto`, *optional*):
+            Chat profile photo visible if the main photo is hidden by privacy settings.
+            This photo isn't returned in the list of chat photos.
+            Suitable for downloads only.
 
         stories (List of :obj:`~pyrogram.types.Story`, *optional*):
             The list of chat's stories if available.
@@ -501,6 +512,10 @@ class Chat(Object):
             Information about gifts that can be received by the user.
             Returned only in :meth:`~pyrogram.Client.get_chat`
 
+        note (:obj:`~pyrogram.types.FormattedText`, *optional*):
+            Note added to the user's contact.
+            Returned only in :meth:`~pyrogram.Client.get_chat`
+
         raw (:obj:`~pyrogram.raw.types.UserFull` | :obj:`~pyrogram.raw.types.ChatFull` | :obj:`~pyrogram.raw.types.ChannelFull`, *optional*):
             The raw chat or user object, as received from the Telegram API.
 
@@ -538,7 +553,9 @@ class Chat(Object):
         usernames: Optional[List["types.Username"]] = None,
         first_name: Optional[str] = None,
         last_name: Optional[str] = None,
+        personal_photo: Optional["types.ChatPhoto"] = None,
         photo: Optional["types.ChatPhoto"] = None,
+        public_photo: Optional["types.ChatPhoto"] = None,
         stories: Optional[List["types.Story"]] = None,
         chat_background: Optional["types.ChatBackground"] = None,
         bio: Optional[str] = None,
@@ -642,6 +659,7 @@ class Chat(Object):
         is_paid_messages_available: Optional[bool] = None,
         display_gifts_button: Optional[bool] = None,
         accepted_gift_types: Optional["types.AcceptedGiftTypes"] = None,
+        note: Optional["types.FormattedText"] = None,
         raw: Optional[Union["raw.types.UserFull", "raw.types.ChatFull", "raw.types.ChannelFull"]] = None
     ):
         super().__init__(client)
@@ -673,7 +691,9 @@ class Chat(Object):
         self.usernames = usernames
         self.first_name = first_name
         self.last_name = last_name
+        self.personal_photo = personal_photo
         self.photo = photo
+        self.public_photo = public_photo
         self.stories = stories
         self.chat_background = chat_background
         self.bio = bio
@@ -777,6 +797,7 @@ class Chat(Object):
         self.is_paid_messages_available = is_paid_messages_available
         self.display_gifts_button = display_gifts_button
         self.accepted_gift_types = accepted_gift_types
+        self.note = note
         self.raw = raw
 
     # region Deprecated
@@ -997,10 +1018,10 @@ class Chat(Object):
         parsed_chat.can_view_revenue = user.can_view_revenue
         parsed_chat.bot_can_manage_emoji_status = user.bot_can_manage_emoji_status
         parsed_chat.bio = user.about or None
-        # parsed_chat.personal_photo
-        # parsed_chat.profile_photo
-        # parsed_chat.fallback_photo
-        # parsed_chat.bot_info
+        parsed_chat.personal_photo = types.ChatPhoto._parse(client, user.personal_photo, users[user.id].id, users[user.id].access_hash)
+        # parsed_chat.photo = types.ChatPhoto._parse(client, user.profile_photo, users[user.id].id, users[user.id].access_hash)
+        parsed_chat.public_photo = types.ChatPhoto._parse(client, user.fallback_photo, users[user.id].id, users[user.id].access_hash)
+        # parsed_chat.bot_info = user.bot_info
 
         if user.pinned_msg_id:
             parsed_chat.pinned_message = await client.get_messages(chat_id=parsed_chat.id, pinned=True)
@@ -1011,10 +1032,8 @@ class Chat(Object):
         parsed_chat.private_forward_name = user.private_forward_name
         parsed_chat.chat_admin_rights = types.ChatAdministratorRights._parse(user.bot_group_admin_rights)
         parsed_chat.channel_admin_rights = types.ChatAdministratorRights._parse(user.bot_broadcast_admin_rights)
-        # parsed_chat.premium_gifts
         parsed_chat.chat_background = types.ChatBackground._parse(client, user.wallpaper)
 
-
         if user.stories:
             parsed_chat.stories = types.List(
                 [
@@ -1026,7 +1045,7 @@ class Chat(Object):
             ) or None
 
         parsed_chat.business_work_hours = types.BusinessWorkingHours._parse(user.business_work_hours)
-        parsed_chat.business_location = types.Location._parse(client, user.business_location)
+        parsed_chat.business_location = types.Location._parse_business(user.business_location)
         parsed_chat.business_greeting_message = types.BusinessMessage._parse(client, user.business_greeting_message, users)
         parsed_chat.business_away_message = types.BusinessMessage._parse(client, user.business_away_message, users)
         parsed_chat.business_intro = await types.BusinessIntro._parse(client, user.business_intro)
@@ -1069,6 +1088,7 @@ class Chat(Object):
         parsed_chat.paid_message_star_count = user.send_paid_messages_stars
         parsed_chat.display_gifts_button = user.display_gifts_button
         parsed_chat.accepted_gift_types = types.AcceptedGiftTypes._parse(user.disallowed_gifts)
+        parsed_chat.note = types.FormattedText._parse(client, user.note)
 
         return parsed_chat
 
